@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2016                                                    *
+ *   copyright (C) 2016-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -26,8 +26,9 @@ void ChildWidgetPlacementPin::detectConnectedSide()
 
 }
 
-void ChildWidgetPlacementPin::setInitialPosition()
+void ChildWidgetPlacementPin::setInitialPosition(const QPointF &scenePos)
 {
+    Q_UNUSED(scenePos);
     m_connectedSide = Top;
     setPos(0, - height() ); // place above parent
 }
